# Copyright 2016 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import io
import os

from setuptools import find_packages
from setuptools import setup


PACKAGE_ROOT = os.path.abspath(os.path.dirname(__file__))

with io.open(os.path.join(PACKAGE_ROOT, 'README.rst'), 'r') as readme_file:
    readme = readme_file.read()


setup(
    author='Google Cloud Platform',
    author_email='googleapis-packages@google.com',
    name='google-cloud-videointelligence',
    version='0.25.0',
    description='Python Client for Google Cloud Video Intelligence',
    long_description=readme,
    namespace_packages=[
        'google',
        'google.cloud',
        'google.cloud.gapic',
        'google.cloud.gapic.videointelligence',
        'google.cloud.proto',
        'google.cloud.proto.videointelligence',
    ],
    packages=find_packages(exclude=('tests*',)),
    install_requires=(
        'googleapis-common-protos >= 1.5.2, < 2.0dev',
        'google-gax >= 0.15.12, < 0.16dev',
        'six >= 1.10.0',
    ),
    url='https://github.com/GoogleCloudPlatform/google-cloud-python',
    license='Apache 2.0',
    platforms='Posix; MacOS X; Windows',
    include_package_data=True,
    zip_safe=False,
    scripts=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet',
    ],
)
